Class: ActiveRecord::ConnectionAdapters::PostgreSQLAdapter

Inherits:
AbstractAdapter
  • Object
show all
Defined in:
lib/pg_query_analyzer.rb

Constant Summary collapse

@@analyzer_debug =
0..2
@@analyzer_warn =
3..7
@@explain_analyze =

ANALYZE carries out the command and show the actual run times.

true
@@explain_verbose =

VERBOSE shows the full plan tree, rather than a summary.

true

Instance Method Summary collapse

Instance Method Details

#select_logger(time_spent, log) ⇒ Object



8
9
10
11
12
13
14
# File 'lib/pg_query_analyzer.rb', line 8

def select_logger time_spent, log
  case time_spent
  when @@analyzer_debug then @logger.debug(log)
  when @@analyzer_warn  then @logger.warn(log)
  else @logger.fatal(log)
  end
end